# SPDX-License-Identifier: MIT
# Copyright (c) 2025 Hammerheads Engineers Sp. z o.o.
# See the accompanying LICENSE file for terms.

from spx_sdk.components import SpxComponent


class Protocol(SpxComponent):
    """
    Protocol class for managing protocol components.
    Inherits from SpxContainer to manage a collection of components.
    """
    pass
